@@ -2,7 +2,7 @@
 from ansible.module_utils.hashivault import hashivault_auth_client
 from ansible.module_utils.hashivault import hashivault_argspec
 from ansible.module_utils.hashivault import hashivault_init
-from ansible.module_utils.hashivault import compare_state
+from ansible.module_utils.hashivault import is_state_changed
 from ansible.module_utils.hashivault import hashiwrapper
 
 ANSIBLE_METADATA = {'status': ['preview'], 'supported_by': 'community', 'version': '1.1'}
@@ -92,7 +92,7 @@ def hashivault_pki_url(module):
 
     # compare current_state to desired_state
     if not changed:
-        changed = not compare_state(desired_state, current_state)
+        changed = is_state_changed(desired_state, current_state)
 
     # make the changes!
     if changed and not module.check_mode:
