@@ -14,7 +14,7 @@ module: hashivault_write
 version_added: "0.1"
 short_description: Hashicorp Vault write module
 description:
-    - Module to write to Hashicorp Vault.
+    - Module to write to Hashicorp Vault. Consider using `hashivault_secret` instead.
 options:
     version:
         description:
@@ -102,7 +102,7 @@ def hashivault_write(module):
             if version == 2:
                 read_data = client.secrets.kv.v2.read_secret_version(secret, mount_point=mount_point)
             else:
-                read_data = client.read(secret_path) or {}
+                read_data = client.secrets.kv.v1.read_secret(secret, mount_point=mount_point)
         except InvalidPath:
             read_data = None
         except Exception as e:
